# -*- coding: utf-8 -*-
from typing import Any, ContextManager, Optional, Union

class XmlResource(Object):
    """ This is the main class for interacting with the XML-based resource
system.

        Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    def AddHandler(self, handler: 'xrc.XmlResourceHandler') -> None:
        """ Initializes only a specific handler (or custom handler).

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    @staticmethod
    def AddSubclassFactory(factory: 'xrc.XmlSubclassFactory') -> None:
        """ Registers subclasses factory for use in XRC.

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    def AttachUnknownControl(self, name, control, parent=None) -> bool:
        """ Attaches an unknown control to the given panel/window/dialog.

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    def ClearHandlers(self) -> None:
        """ Removes all handlers and deletes them (this means that any handlers added using AddHandler   must be allocated on the heap).

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    def CompareVersion(self, major, minor, release, revision) -> int:
        """ Compares the XRC version to the argument.

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    @staticmethod
    def FindXRCIDById(numId: int) -> str:
        """ Returns a string ID corresponding to the given numeric ID.

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    @staticmethod
    def Get() -> 'xrc.XmlResource':
        """ Gets the global resources object or creates one if none exists.

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    def GetDomain(self) -> str:
        """ Returns the domain (message catalog) that will be used to load translatable strings in the XRC.

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    def GetFlags(self) -> int:
        """ Returns flags, which may be a bitlist of   wx.xrc.XmlResourceFlags  enumeration values.

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    def GetResourceNode(self, name: str) -> 'xml.XmlNode':
        """ Returns the   wx.xml.XmlNode  containing the definition of the object with the given name or None.

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    def GetVersion(self) -> int:
        """ Returns version information (a.b.c.d = d + 256c + 2562b + 2563a).

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    @staticmethod
    def GetXRCID(str_id, value_if_not_found=ID_NONE) -> int:
        """ Returns a numeric ID that is equivalent to the string ID used in an XML resource.

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    def InitAllHandlers(self) -> None:
        """ Initializes handlers for all supported controls/windows.

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    def InsertHandler(self, handler: 'xrc.XmlResourceHandler') -> None:
        """ Add a new handler at the beginning of the handler list.

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    def Load(self, filemask: str) -> bool:
        """ Loads resources from XML files that match given filemask.

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    def LoadAllFiles(self, dirname: str) -> bool:
        """ Loads all .xrc files from directory dirname.

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    def LoadBitmap(self, name: str) -> 'Bitmap':
        """ Loads a bitmap resource from a file.

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    def LoadDialog(self, *args, **kw) -> 'Dialog':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    def LoadDocument(self, doc, name="") -> bool:
        """ Load resources from the XML document containing them.

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    def LoadFile(self, file: str) -> bool:
        """ Simpler form of Load   for loading a single XRC file.

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    def LoadFrame(self, *args, **kw) -> 'Frame':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    def LoadFromBuffer(self, data) -> bool:
        """ Load the resource from a bytes string or other data buffer compatible object.

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    def LoadIcon(self, name: str) -> 'Icon':
        """ Loads an icon resource from a file.

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    def LoadMenu(self, name: str) -> 'Menu':
        """ Loads menu from resource.

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    def LoadMenuBar(self, *args, **kw) -> 'MenuBar':
        """ Loads a menubar from resource.

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    def LoadObject(self, *args, **kw) -> 'Window':
        """ Load an object from the resource specifying both the resource name and the class name.

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    def LoadObjectRecursively(self, *args, **kw) -> 'Window':
        """ Load an object from anywhere in the resource tree.

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    def LoadPanel(self, *args, **kw) -> 'Panel':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    def LoadToolBar(self, parent, name) -> 'ToolBar':
        """ Loads a toolbar.

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    @staticmethod
    def Set(res: 'xrc.XmlResource') -> 'xrc.XmlResource':
        """ Sets the global resources object and returns a pointer to the previous one (may be None).

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    def SetDomain(self, domain: str) -> None:
        """ Sets the domain (message catalog) that will be used to load translatable strings in the XRC.

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    def SetFlags(self, flags: int) -> None:
        """ Sets flags (bitlist of   wx.xrc.XmlResourceFlags  enumeration values).

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    def Unload(self, filename: str) -> bool:
        """ This function unloads a resource previously loaded by Load .

            Source: https://docs.wxpython.org/wx.xrc.XmlResource.html
        """

    Domain: str  # See GetDomain and SetDomain
    Flags: int  # See GetFlags and SetFlags
    Version: int  # See GetVersion



class XmlResourceHandler(Object):
    """ SizerXmlHandler is a class for resource handlers capable of creating
a Sizer object from an XML node.

        Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
    """
    def __init__(self) -> None:
        """ Default constructor.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def AddStyle(self, name, value) -> None:
        """ Add a style flag (e.g.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def AddWindowStyles(self) -> None:
        """ Add styles common to all Window-derived classes.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def CanHandle(self, node: 'xml.XmlNode') -> bool:
        """ Returns True if it understands this node and can create a resource from it, False otherwise.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def CreateChildren(self, parent, this_hnd_only=False) -> None:
        """ Creates children.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def CreateChildrenPrivately(self, parent, rootnode=None) -> None:
        """ Helper function.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def CreateResFromNode(self, node, parent, instance=None) -> 'Window':
        """ Creates a resource from a node.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def CreateResource(self, node, parent, instance) -> 'Window':
        """ Creates an object (menu, dialog, control, â¦) from an XML node.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def DoCreateResource(self) -> 'Window':
        """ Called from CreateResource after variables were filled.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetAnimation(self, param="animation", ctrl=None) -> 'adv.Animation':
        """ Creates an animation (see   wx.adv.Animation) from the filename specified in param.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetBitmap(self, *args, **kw) -> 'Bitmap':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetBitmapBundle(self, *args, **kw) -> 'BitmapBundle':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetBool(self, param, defaultv=False) -> bool:
        """ Gets a bool flag (1, t, yes, on, True are True, everything else is False).

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetClass(self) -> str:
        """ After CreateResource has been called this will return the class name of the XML resource node being processed.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetColour(self, param, defaultColour=NullColour) -> 'Colour':
        """ Gets colour in HTML syntax (#``RRGGBB``).

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetCurFileSystem(self) -> 'FileSystem':
        """ Returns the current file system.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetDimension(self, param, defaultv=0, windowToUse=0) -> 'Coord':
        """ Gets a dimension (may be in dialog units).

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetDirection(self, param, dirDefault=LEFT) -> int:
        """ Gets a direction.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetFloat(self, param, defaultv=0) -> float:
        """ Gets a float value from the parameter.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetFont(self, param: str="font") -> 'Font':
        """ Gets a font.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetID(self) -> int:
        """ Returns the wx.xrc.XRCID.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetIcon(self, *args, **kw) -> 'Icon':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetIconBundle(self, param, defaultArtClient=ART_OTHER) -> 'IconBundle':
        """ Returns an icon bundle.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetImageList(self, param: str="imagelist") -> 'ImageList':
        """ Creates an image list from the param  markup data.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetInstance(self) -> 'Window':
        """ After CreateResource has been called this will return the instance that the XML resource content should be created upon, if it has already been created.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetLong(self, param, defaultv=0) -> int:
        """ Gets the integer value from the parameter.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetName(self) -> str:
        """ Returns the resource name.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetNode(self) -> 'xml.XmlNode':
        """ After CreateResource has been called this will return the XML node being processed.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetNodeChildren(self, node: 'xml.XmlNode') -> 'xml.XmlNode':
        """ Gets the first child of the given node or None.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetNodeContent(self, node: 'xml.XmlNode') -> str:
        """ Gets node content from wx.xml.XML_ENTITY_NODE.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetNodeNext(self, node: 'xml.XmlNode') -> 'xml.XmlNode':
        """ Gets the next sibling node related to the given node, possibly None.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetNodeParent(self, node: 'xml.XmlNode') -> 'xml.XmlNode':
        """ Gets the parent of the node given.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetParamNode(self, param: str) -> 'xml.XmlNode':
        """ Finds the node or returns None.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetParamValue(self, *args, **kw) -> str:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetParent(self) -> 'Window':
        """ After CreateResource has been called this will return the current itemâs parent, if any.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetParentAsWindow(self) -> 'Window':
        """ After CreateResource has been called this will return the itemâs parent as a   wx.Window.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetPosition(self, param: str="pos") -> 'Point':
        """ Gets the position (may be in dialog units).

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetResource(self) -> 'xrc.XmlResource':
        """ After CreateResource has been called this will return the current   wx.xrc.XmlResource  object.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetSize(self, param="size", windowToUse=0) -> 'Size':
        """ Gets the size (may be in dialog units).

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetStyle(self, param="style", defaults=0) -> int:
        """ Gets style flags from text in form âflag | flag2| flag3 |â¦â Only understands flags added with AddStyle .

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def GetText(self, param, translate=True) -> str:
        """ Gets text from param and does some conversions:

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def HasParam(self, param: str) -> bool:
        """ Check to see if a parameter exists.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def IsObjectNode(self, node: 'xml.XmlNode') -> bool:
        """ Checks if the given node is an object node.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def IsOfClass(self, node, classname) -> bool:
        """ Convenience function.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def ReportError(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def ReportParamError(self, param, message) -> None:
        """ Like ReportError , but uses the node of parameter param  of the currently processed object as the context.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def SetParentResource(self, res: 'xrc.XmlResource') -> None:
        """ Sets the parent resource.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    def SetupWindow(self, wnd: 'Window') -> None:
        """ Sets common window options.

            Source: https://docs.wxpython.org/wx.xrc.XmlResourceHandler.html
        """

    Animation: 'adv.Animation'  # See GetAnimation
    Bitmap: 'Bitmap'  # See GetBitmap
    BitmapBundle: 'BitmapBundle'  # See GetBitmapBundle
    Class: str  # See GetClass
    CurFileSystem: 'FileSystem'  # See GetCurFileSystem
    Font: 'Font'  # See GetFont
    ID: int  # See GetID
    Icon: 'Icon'  # See GetIcon
    ImageList: 'ImageList'  # See GetImageList
    Instance: 'Window'  # See GetInstance
    Name: str  # See GetName
    Node: 'xml.XmlNode'  # See GetNode
    Parent: 'Window'  # See GetParent
    ParentAsWindow: 'Window'  # See GetParentAsWindow
    Position: 'Point'  # See GetPosition
    Resource: 'xrc.XmlResource'  # See GetResource
    Size: 'Size'  # See GetSize
    Style: int  # See GetStyle



XRCID: int

XML_ENTITY_NODE: int

XRC_USE_LOCALE: int

XRC_NO_SUBCLASSING: int

XRC_NO_RELOADING: int

XRC_USE_ENVVARS: int

class XmlSubclassFactory:
    """ className (String) â 

        Source: https://docs.wxpython.org/wx.xrc.XmlSubclassFactory.html
    """
    def __init__(self) -> None:
        """ 

            Source: https://docs.wxpython.org/wx.xrc.XmlSubclassFactory.html
        """

    def Create(self, className: str) -> 'Window':
        """ className (String) â

            Source: https://docs.wxpython.org/wx.xrc.XmlSubclassFactory.html
        """






# -*- coding: utf-8 -*-
from typing import Any, ContextManager, Optional, Union

class XmlDocument(Object):
    """ This class holds XML data/document as parsed by XML parser in the root
node.

        Source: https://docs.wxpython.org/wx.xml.XmlDocument.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.xml.XmlDocument.html
        """

    def AppendToProlog(self, node: 'xml.XmlNode') -> None:
        """ Appends a Process Instruction or Comment node to the document prologue.

            Source: https://docs.wxpython.org/wx.xml.XmlDocument.html
        """

    def DetachDocumentNode(self) -> 'xml.XmlNode':
        """ Detaches the document node and returns it.

            Source: https://docs.wxpython.org/wx.xml.XmlDocument.html
        """

    def DetachRoot(self) -> 'xml.XmlNode':
        """ Detaches the root entity node and returns it.

            Source: https://docs.wxpython.org/wx.xml.XmlDocument.html
        """

    def GetDoctype(self) -> 'xml.XmlDoctype':
        """ Returns the DOCTYPE declaration data for the document.

            Source: https://docs.wxpython.org/wx.xml.XmlDocument.html
        """

    def GetDocumentNode(self) -> 'xml.XmlNode':
        """ Returns the document node of the document.

            Source: https://docs.wxpython.org/wx.xml.XmlDocument.html
        """

    def GetEOL(self) -> str:
        """ Returns the output line ending string used for documents.

            Source: https://docs.wxpython.org/wx.xml.XmlDocument.html
        """

    def GetFileEncoding(self) -> str:
        """ Returns encoding of document (may be empty).

            Source: https://docs.wxpython.org/wx.xml.XmlDocument.html
        """

    def GetFileType(self) -> 'TextFileType':
        """ Returns the output line ending format used for documents.

            Source: https://docs.wxpython.org/wx.xml.XmlDocument.html
        """

    @staticmethod
    def GetLibraryVersionInfo() -> 'VersionInfo':
        """ Get expat library version information.

            Source: https://docs.wxpython.org/wx.xml.XmlDocument.html
        """

    def GetRoot(self) -> 'xml.XmlNode':
        """ Returns the root element node of the document.

            Source: https://docs.wxpython.org/wx.xml.XmlDocument.html
        """

    def GetVersion(self) -> str:
        """ Returns the version of document.

            Source: https://docs.wxpython.org/wx.xml.XmlDocument.html
        """

    def IsOk(self) -> bool:
        """ Returns True if the document has been loaded successfully.

            Source: https://docs.wxpython.org/wx.xml.XmlDocument.html
        """

    def Load(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.xml.XmlDocument.html
        """

    def Save(self, *args, **kw) -> bool:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.xml.XmlDocument.html
        """

    def SetDoctype(self, doctype: 'xml.XmlDoctype') -> None:
        """ Sets the data which will appear in the DOCTYPE declaration when the document is saved.

            Source: https://docs.wxpython.org/wx.xml.XmlDocument.html
        """

    def SetDocumentNode(self, node: 'xml.XmlNode') -> None:
        """ Sets the document node of this document.

            Source: https://docs.wxpython.org/wx.xml.XmlDocument.html
        """

    def SetFileEncoding(self, encoding: str) -> None:
        """ Sets the encoding of the file which will be used to save the document.

            Source: https://docs.wxpython.org/wx.xml.XmlDocument.html
        """

    def SetFileType(self, fileType: TextFileType) -> None:
        """ Sets the output line ending formats when the document is saved.

            Source: https://docs.wxpython.org/wx.xml.XmlDocument.html
        """

    def SetRoot(self, node: 'xml.XmlNode') -> None:
        """ Sets the root element node of this document.

            Source: https://docs.wxpython.org/wx.xml.XmlDocument.html
        """

    def SetVersion(self, version: str) -> None:
        """ Sets the version of the XML file which will be used to save the document.

            Source: https://docs.wxpython.org/wx.xml.XmlDocument.html
        """

    Doctype: 'xml.XmlDoctype'  # See GetDoctype and SetDoctype
    DocumentNode: 'xml.XmlNode'  # See GetDocumentNode and SetDocumentNode
    EOL: str  # See GetEOL
    FileEncoding: str  # See GetFileEncoding and SetFileEncoding
    FileType: TextFileType  # See GetFileType and SetFileType
    Root: 'xml.XmlNode'  # See GetRoot and SetRoot
    Version: str  # See GetVersion and SetVersion



XMLDOC_KEEP_WHITESPACE_NODES: int

class XmlNode:
    """ Represents a node in an XML document.

        Source: https://docs.wxpython.org/wx.xml.XmlNode.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.xml.XmlNode.html
        """

    def AddAttribute(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.xml.XmlNode.html
        """

    def AddChild(self, child: 'xml.XmlNode') -> None:
        """ Adds node child  as the last child of this node.

            Source: https://docs.wxpython.org/wx.xml.XmlNode.html
        """

    def DeleteAttribute(self, name: str) -> bool:
        """ Removes the first attributes which has the given name  from the list of attributes for this node.

            Source: https://docs.wxpython.org/wx.xml.XmlNode.html
        """

    def GetAttribute(self, attrName, defaultVal="") -> str:
        """ Returns the value of the attribute named attrName  if it does exist.

            Source: https://docs.wxpython.org/wx.xml.XmlNode.html
        """

    def GetAttributes(self) -> 'xml.XmlAttribute':
        """ Return a pointer to the first attribute of this node.

            Source: https://docs.wxpython.org/wx.xml.XmlNode.html
        """

    def GetChildren(self) -> 'xml.XmlNode':
        """ Returns the first child of this node.

            Source: https://docs.wxpython.org/wx.xml.XmlNode.html
        """

    def GetContent(self) -> str:
        """ Returns the content of this node.

            Source: https://docs.wxpython.org/wx.xml.XmlNode.html
        """

    def GetDepth(self, grandparent: Optional['xml.XmlNode']=None) -> int:
        """ Returns the number of nodes which separate this node from  grandparent .

            Source: https://docs.wxpython.org/wx.xml.XmlNode.html
        """

    def GetLineNumber(self) -> int:
        """ Returns line number of the node in the input XML file or  -1   if it is unknown.

            Source: https://docs.wxpython.org/wx.xml.XmlNode.html
        """

    def GetName(self) -> str:
        """ Returns the name of this node.

            Source: https://docs.wxpython.org/wx.xml.XmlNode.html
        """

    def GetNext(self) -> 'xml.XmlNode':
        """ Returns a pointer to the sibling of this node or None if there are no siblings.

            Source: https://docs.wxpython.org/wx.xml.XmlNode.html
        """

    def GetNoConversion(self) -> bool:
        """ Returns a flag indicating whether encoding conversion is necessary when saving.

            Source: https://docs.wxpython.org/wx.xml.XmlNode.html
        """

    def GetNodeContent(self) -> str:
        """ Returns the content of the first child node of type  XML_TEXT_NODE   or   XML_CDATA_SECTION_NODE .

            Source: https://docs.wxpython.org/wx.xml.XmlNode.html
        """

    def GetParent(self) -> 'xml.XmlNode':
        """ Returns a pointer to the parent of this node or None if this node has no parent.

            Source: https://docs.wxpython.org/wx.xml.XmlNode.html
        """

    def GetType(self) -> 'xml.XmlNodeType':
        """ Returns the type of this node.

            Source: https://docs.wxpython.org/wx.xml.XmlNode.html
        """

    def HasAttribute(self, attrName: str) -> bool:
        """ Returns True if this node has a attribute named attrName.

            Source: https://docs.wxpython.org/wx.xml.XmlNode.html
        """

    def InsertChild(self, child, followingNode) -> bool:
        """ Inserts the child  node immediately before followingNode  in the children list.

            Source: https://docs.wxpython.org/wx.xml.XmlNode.html
        """

    def InsertChildAfter(self, child, precedingNode) -> bool:
        """ Inserts the child  node immediately after precedingNode  in the children list.

            Source: https://docs.wxpython.org/wx.xml.XmlNode.html
        """

    def IsWhitespaceOnly(self) -> bool:
        """ Returns True if the content of this node is a string containing only whitespaces (spaces, tabs, new lines, etc).

            Source: https://docs.wxpython.org/wx.xml.XmlNode.html
        """

    def RemoveChild(self, child: 'xml.XmlNode') -> bool:
        """ Removes the given node from the children list.

            Source: https://docs.wxpython.org/wx.xml.XmlNode.html
        """

    def SetContent(self, con: str) -> None:
        """ Sets the content of this node.

            Source: https://docs.wxpython.org/wx.xml.XmlNode.html
        """

    def SetName(self, name: str) -> None:
        """ Sets the name of this node.

            Source: https://docs.wxpython.org/wx.xml.XmlNode.html
        """

    def SetNext(self, next: 'xml.XmlNode') -> None:
        """ Sets as sibling the given node.

            Source: https://docs.wxpython.org/wx.xml.XmlNode.html
        """

    def SetNoConversion(self, noconversion: bool) -> None:
        """ Sets a flag to indicate whether encoding conversion is necessary when saving.

            Source: https://docs.wxpython.org/wx.xml.XmlNode.html
        """

    def SetParent(self, parent: 'xml.XmlNode') -> None:
        """ Sets as parent the given node.

            Source: https://docs.wxpython.org/wx.xml.XmlNode.html
        """

    def SetType(self, type: XmlNodeType) -> None:
        """ Sets the type of this node.

            Source: https://docs.wxpython.org/wx.xml.XmlNode.html
        """

    Attributes: 'xml.XmlAttribute'  # See GetAttributes
    Children: 'xml.XmlNode'  # See GetChildren
    Content: str  # See GetContent and SetContent
    Depth: int  # See GetDepth
    LineNumber: int  # See GetLineNumber
    Name: str  # See GetName and SetName
    Next: 'xml.XmlNode'  # See GetNext and SetNext
    NoConversion: bool  # See GetNoConversion and SetNoConversion
    NodeContent: str  # See GetNodeContent
    Parent: 'xml.XmlNode'  # See GetParent and SetParent
    Type: XmlNodeType  # See GetType and SetType



class XmlAttribute:
    """ Represents a node attribute.

        Source: https://docs.wxpython.org/wx.xml.XmlAttribute.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.xml.XmlAttribute.html
        """

    def GetName(self) -> str:
        """ Returns the name of this attribute.

            Source: https://docs.wxpython.org/wx.xml.XmlAttribute.html
        """

    def GetNext(self) -> 'xml.XmlAttribute':
        """ Returns the sibling of this attribute or None if there are no siblings.

            Source: https://docs.wxpython.org/wx.xml.XmlAttribute.html
        """

    def GetValue(self) -> str:
        """ Returns the value of this attribute.

            Source: https://docs.wxpython.org/wx.xml.XmlAttribute.html
        """

    def SetName(self, name: str) -> None:
        """ Sets the name of this attribute.

            Source: https://docs.wxpython.org/wx.xml.XmlAttribute.html
        """

    def SetNext(self, next: 'xml.XmlAttribute') -> None:
        """ Sets the sibling of this attribute.

            Source: https://docs.wxpython.org/wx.xml.XmlAttribute.html
        """

    def SetValue(self, value: str) -> None:
        """ Sets the value of this attribute.

            Source: https://docs.wxpython.org/wx.xml.XmlAttribute.html
        """

    Name: str  # See GetName and SetName
    Next: 'xml.XmlAttribute'  # See GetNext and SetNext
    Value: str  # See GetValue and SetValue



class XmlDoctype:
    """ Represents a DOCTYPE Declaration.

        Source: https://docs.wxpython.org/wx.xml.XmlDoctype.html
    """
    def __init__(self, rootName="", systemId="", publicId="") -> None:
        """ Creates and possible initializes the DOCTYPE.

            Source: https://docs.wxpython.org/wx.xml.XmlDoctype.html
        """

    def Clear(self) -> None:
        """ Removes all the DOCTYPE values.

            Source: https://docs.wxpython.org/wx.xml.XmlDoctype.html
        """

    def GetFullString(self) -> str:
        """ Returns the formatted DOCTYPE contents.

            Source: https://docs.wxpython.org/wx.xml.XmlDoctype.html
        """

    def GetPublicId(self) -> str:
        """ Returns the public id of the document.

            Source: https://docs.wxpython.org/wx.xml.XmlDoctype.html
        """

    def GetRootName(self) -> str:
        """ Returns the root name of the document.

            Source: https://docs.wxpython.org/wx.xml.XmlDoctype.html
        """

    def GetSystemId(self) -> str:
        """ Returns the system id of the document.

            Source: https://docs.wxpython.org/wx.xml.XmlDoctype.html
        """

    def IsValid(self) -> bool:
        """ Returns True if the contents can produce a valid DOCTYPE string.

            Source: https://docs.wxpython.org/wx.xml.XmlDoctype.html
        """

    FullString: str  # See GetFullString
    PublicId: str  # See GetPublicId
    RootName: str  # See GetRootName
    SystemId: str  # See GetSystemId



XML_ELEMENT_NODE: int

XML_ATTRIBUTE_NODE: int

XML_TEXT_NODE: int

XML_CDATA_SECTION_NODE: int

XML_ENTITY_REF_NODE: int

XML_ENTITY_NODE: int

XML_PI_NODE: int

XML_COMMENT_NODE: int

XML_DOCUMENT_NODE: int

XML_DOCUMENT_TYPE_NODE: int

XML_DOCUMENT_FRAG_NODE: int

XML_NOTATION_NODE: int

XML_HTML_DOCUMENT_NODE: int




# -*- coding: utf-8 -*-
from typing import Any, ContextManager, Optional, Union

class WebView(Control):
    """ This control may be used to render web (HTML / CSS / javascript)
documents.

        Source: https://docs.wxpython.org/wx.html2.WebView.html
    """
    def AddScriptMessageHandler(self, name: str) -> bool:
        """ Add a script message handler with the given name.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def AddUserScript(self, javascript, injectionTime=WEBVIEW_INJECT_AT_DOCUMENT_START) -> bool:
        """ Injects the specified script into the webpageâs content.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def CanCopy(self) -> bool:
        """ Returns True if the current selection can be copied.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def CanCut(self) -> bool:
        """ Returns True if the current selection can be cut.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def CanGoBack(self) -> bool:
        """ Returns True if it is possible to navigate backward in the history of visited pages.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def CanGoForward(self) -> bool:
        """ Returns True if it is possible to navigate forward in the history of visited pages.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def CanPaste(self) -> bool:
        """ Returns True if data can be pasted.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def CanRedo(self) -> bool:
        """ Returns True if there is an action to redo.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def CanSetZoomType(self, type: WebViewZoomType) -> bool:
        """ Retrieve whether the current HTML engine supports a zoom type.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def CanUndo(self) -> bool:
        """ Returns True if there is an action to undo.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def ClearHistory(self) -> None:
        """ Clear the history, this will also remove the visible page.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def ClearSelection(self) -> None:
        """ Clears the current selection.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def Copy(self) -> None:
        """ Copies the current selection.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def Create(self, parent, id=ID_ANY, url=WebViewDefaultURLStr, pos=DefaultPosition, size=DefaultSize, style=0, name=WebViewNameStr) -> bool:
        """ Creation function for two-step creation.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def Cut(self) -> None:
        """ Cuts the current selection.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def DeleteSelection(self) -> None:
        """ Deletes the current selection.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def EnableAccessToDevTools(self, enable: bool=True) -> None:
        """ Enable or disable access to dev tools for the user.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def EnableContextMenu(self, enable: bool=True) -> None:
        """ Enable or disable the right click context menu.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def EnableHistory(self, enable: bool=True) -> None:
        """ Enable or disable the history.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def Find(self, text, flags=WEBVIEW_FIND_DEFAULT) -> int:
        """ Finds a phrase on the current page and if found, the control will scroll the phrase into view and select it.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    @staticmethod
    def GetBackendVersionInfo(backend: str=WebViewBackendDefault) -> VersionInfo:
        """ Retrieve the version information about the backend implementation.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def GetBackwardHistory(self) -> Any:
        """ Returns a list of items in the back history.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    @staticmethod
    def GetClassDefaultAttributes(variant: int=WINDOW_VARIANT_NORMAL) -> VisualAttributes:
        """ variant (WindowVariant) â

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def GetCurrentTitle(self) -> str:
        """ Get the title of the current web page, or its URL/path if title is not available.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def GetCurrentURL(self) -> str:
        """ Get the URL of the currently displayed document.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def GetForwardHistory(self) -> Any:
        """ Returns a list of items in the forward history.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def GetNativeBackend(self) -> None:
        """ Return the pointer to the native backend used by this control.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def GetPageSource(self) -> str:
        """ Get the HTML source code of the currently displayed document.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def GetPageText(self) -> str:
        """ Get the text of the current page.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def GetSelectedSource(self) -> str:
        """ Returns the currently selected source, if any.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def GetSelectedText(self) -> str:
        """ Returns the currently selected text, if any.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def GetUserAgent(self) -> str:
        """ Returns the current user agent string for the web view.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def GetZoom(self) -> 'html2.WebViewZoom':
        """ Get the zoom level of the page.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def GetZoomFactor(self) -> float:
        """ Get the zoom factor of the page.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def GetZoomType(self) -> 'html2.WebViewZoomType':
        """ Get how the zoom factor is currently interpreted.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def GoBack(self) -> None:
        """ Navigate back in the history of visited pages.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def GoForward(self) -> None:
        """ Navigate forward in the history of visited pages.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def HasSelection(self) -> bool:
        """ Returns True if there is a current selection.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def IsAccessToDevToolsEnabled(self) -> bool:
        """ Returns True if dev tools are available to the user.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    @staticmethod
    def IsBackendAvailable(backend: str) -> bool:
        """ Allows to check if a specific backend is currently available.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def IsBusy(self) -> bool:
        """ Returns whether the web control is currently busy (e.g. loading a page).

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def IsContextMenuEnabled(self) -> bool:
        """ Returns True if a context menu will be shown on right click.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def IsEditable(self) -> bool:
        """ Returns whether the web control is currently editable.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def LoadURL(self, url: str) -> None:
        """ Load a web page from a URL.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    @staticmethod
    def MSWSetEmulationLevel(level: WebViewIE_EmulationLevel=WEBVIEWIE_EMU_IE11) -> bool:
        """ Sets emulation level.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    @staticmethod
    def MSWSetModernEmulationLevel(modernLevel: bool=True) -> bool:
        """ Please explicitly specify emulation level with MSWSetEmulationLevel .

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    @staticmethod
    def New(*args, **kw) -> 'html2.WebView':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def Paste(self) -> None:
        """ Pastes the current data.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def Print(self) -> None:
        """ Opens a print dialog so that the user may print the currently displayed page.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def Redo(self) -> None:
        """ Redos the last action.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    @staticmethod
    def RegisterFactory(backend, factory) -> None:
        """ Allows the registering of new backend for   wx.html2.WebView.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def RegisterHandler(self, handler: 'html2.WebViewHandler') -> None:
        """ Registers a custom scheme handler.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def Reload(self, flags: WebViewReloadFlags=WEBVIEW_RELOAD_DEFAULT) -> None:
        """ Reload the currently displayed URL.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def RemoveAllUserScripts(self) -> None:
        """ Removes all user scripts from the web view.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def RemoveScriptMessageHandler(self, name: str) -> bool:
        """ Remove a script message handler with the given name that was previously added via AddScriptMessageHandler .

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def RunScript(self, javascript: str) -> tuple:
        """ Runs the given JavaScript code.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def RunScriptAsync(self, javascript, clientData=None) -> None:
        """ Runs the given JavaScript code asynchronously and returns the result via a  wxEVT_WEBVIEW_SCRIPT_RESULT .

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def SelectAll(self) -> None:
        """ Selects the entire page.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def SetEditable(self, enable: bool=True) -> None:
        """ Set the editable property of the web control.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def SetPage(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def SetUserAgent(self, userAgent: str) -> bool:
        """ Specify a custom user agent string for the web view.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def SetZoom(self, zoom: WebViewZoom) -> None:
        """ Set the zoom level of the page.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def SetZoomFactor(self, zoom: float) -> None:
        """ Set the zoom factor of the page.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def SetZoomType(self, zoomType: WebViewZoomType) -> None:
        """ Set how to interpret the zoom factor.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def Stop(self) -> None:
        """ Stop the current page loading process, if any.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    def Undo(self) -> None:
        """ Undos the last action.

            Source: https://docs.wxpython.org/wx.html2.WebView.html
        """

    BackwardHistory: Any  # See GetBackwardHistory
    CurrentTitle: str  # See GetCurrentTitle
    CurrentURL: str  # See GetCurrentURL
    ForwardHistory: Any  # See GetForwardHistory
    NativeBackend: None  # See GetNativeBackend
    PageSource: str  # See GetPageSource
    PageText: str  # See GetPageText
    SelectedSource: str  # See GetSelectedSource
    SelectedText: str  # See GetSelectedText
    UserAgent: str  # See GetUserAgent and SetUserAgent
    Zoom: WebViewZoom  # See GetZoom and SetZoom
    ZoomFactor: float  # See GetZoomFactor and SetZoomFactor
    ZoomType: WebViewZoomType  # See GetZoomType and SetZoomType



EVT_WEBVIEW_NAVIGATING: int  # Process a  wxEVT_WEBVIEW_NAVIGATING   event, generated before trying to get a resource. This event may be vetoed to prevent navigating to this resource. Note that if the displayed HTML document has several frames, one such event will be generated per frame.

EVT_WEBVIEW_NAVIGATED: int  # Process a  wxEVT_WEBVIEW_NAVIGATED   event generated after it was confirmed that a resource would be requested. This event may not be vetoed. Note that if the displayed HTML document has several frames, one such event will be generated per frame.

EVT_WEBVIEW_LOADED: int  # Process a  wxEVT_WEBVIEW_LOADED   event generated when the document is fully loaded and displayed. Note that if the displayed HTML document has several frames, one such event will be generated per frame.

EVT_WEBVIEW_ERROR: int  # Process a  wxEVT_WEBVIEW_ERROR   event generated when a navigation error occurs. The integer associated with this event will be a WebNavigationError item. The string associated with this event may contain a backend-specific more precise error message/code.

EVT_WEBVIEW_NEWWINDOW: int  # Process a  wxEVT_WEBVIEW_NEWWINDOW   event, generated when a new window is created. You must handle this event if you want anything to happen, for example to load the page in a new window or tab.

EVT_WEBVIEW_TITLE_CHANGED: int  # Process a  wxEVT_WEBVIEW_TITLE_CHANGED   event, generated when the page title changes. Use GetString to get the title.

EVT_WEBVIEW_FULL_SCREEN_CHANGED: int  # Process a  EVT_WEBVIEW_FULL_SCREEN_CHANGED   event, generated when the page wants to enter or leave fullscreen. Use GetInt to get the status. Not implemented for the IE backend and is only available in wxWidgets 3.1.5 or later.

EVT_WEBVIEW_SCRIPT_MESSAGE_RECEIVED: int  # Process a  wxEVT_WEBVIEW_SCRIPT_MESSAGE_RECEIVED   event only available in wxWidgets 3.1.5 or later. For usage details see  AddScriptMessageHandler.

wxEVT_WEBVIEW_SCRIPT_RESULT: int  # Process a  wxEVT_WEBVIEW_SCRIPT_RESULT   event only available in wxWidgets 3.1.6 or later. For usage details see  RunScriptAsync. ^^

WEBVIEW_INJECT_AT_DOCUMENT_START: int

class WebViewEvent(NotifyEvent):
    """ A navigation event holds information about events associated with
WebView objects.

        Source: https://docs.wxpython.org/wx.html2.WebViewEvent.html
    """
    def __init__(self, *args, **kw) -> None:
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.html2.WebViewEvent.html
        """

    def GetMessageHandler(self) -> str:
        """ Get the name of the script handler.

            Source: https://docs.wxpython.org/wx.html2.WebViewEvent.html
        """

    def GetNavigationAction(self) -> 'html2.WebViewNavigationActionFlags':
        """ Get the type of navigation action.

            Source: https://docs.wxpython.org/wx.html2.WebViewEvent.html
        """

    def GetTarget(self) -> str:
        """ Get the name of the target frame which the url of this event has been or will be loaded into.

            Source: https://docs.wxpython.org/wx.html2.WebViewEvent.html
        """

    def GetURL(self) -> str:
        """ Get the URL being visited.

            Source: https://docs.wxpython.org/wx.html2.WebViewEvent.html
        """

    def IsError(self) -> bool:
        """ Returns True the script execution failed.

            Source: https://docs.wxpython.org/wx.html2.WebViewEvent.html
        """

    MessageHandler: str  # See GetMessageHandler
    NavigationAction: 'html2.WebViewNavigationActionFlags'  # See GetNavigationAction
    Target: str  # See GetTarget
    URL: str  # See GetURL



class WebViewFactory(Object):
    """ An abstract factory class for creating WebView backends.

        Source: https://docs.wxpython.org/wx.html2.WebViewFactory.html
    """
    def Create(self, *args, **kw) -> 'html2.WebView':
        """ Overloaded Implementations:

            Source: https://docs.wxpython.org/wx.html2.WebViewFactory.html
        """

    def GetVersionInfo(self) -> VersionInfo:
        """ Retrieve the version information about this backend implementation.

            Source: https://docs.wxpython.org/wx.html2.WebViewFactory.html
        """

    def IsAvailable(self) -> bool:
        """ Function to check if the backend is available at runtime.

            Source: https://docs.wxpython.org/wx.html2.WebViewFactory.html
        """

    VersionInfo: VersionInfo  # See GetVersionInfo



class WebViewHandler:
    """ The base class for handling custom schemes in WebView, for example
to allow virtual file system support.

        Source: https://docs.wxpython.org/wx.html2.WebViewHandler.html
    """
    def __init__(self, scheme: str) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.html2.WebViewHandler.html
        """

    def GetFile(self, uri: str) -> FSFile:
        """ uri (string) â

            Source: https://docs.wxpython.org/wx.html2.WebViewHandler.html
        """

    def GetName(self) -> str:
        """ string

            Source: https://docs.wxpython.org/wx.html2.WebViewHandler.html
        """

    def GetSecurityURL(self) -> str:
        """ string

            Source: https://docs.wxpython.org/wx.html2.WebViewHandler.html
        """

    def SetSecurityURL(self, url: str) -> None:
        """ Sets a custom security URL.

            Source: https://docs.wxpython.org/wx.html2.WebViewHandler.html
        """

    Name: str  # See GetName
    SecurityURL: str  # See GetSecurityURL and SetSecurityURL



class WebViewFSHandler(wx2.WebViewHandler):
    """ A WebView file system handler to support standard FileSystem
protocols of the form  example:page.htm  The handler allows WebView
to use FileSystem in a similar fashion to its use with Html.

        Source: https://docs.wxpython.org/wx.html2.WebViewFSHandler.html
    """
    def __init__(self, scheme: str) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.html2.WebViewFSHandler.html
        """

    def GetFile(self, uri: str) -> FSFile:
        """ uri (string) â

            Source: https://docs.wxpython.org/wx.html2.WebViewFSHandler.html
        """



class WebViewArchiveHandler(wx2.WebViewHandler):
    """ A custom handler for the file scheme which also supports loading from
archives.

        Source: https://docs.wxpython.org/wx.html2.WebViewArchiveHandler.html
    """
    def __init__(self, scheme: str) -> None:
        """ Constructor.

            Source: https://docs.wxpython.org/wx.html2.WebViewArchiveHandler.html
        """

    def GetFile(self, uri: str) -> FSFile:
        """ uri (string) â

            Source: https://docs.wxpython.org/wx.html2.WebViewArchiveHandler.html
        """



WEBVIEW_INJECT_AT_DOCUMENT_END: int

WEBVIEW_ZOOM_TYPE_LAYOUT: int

WEBVIEW_ZOOM_TYPE_TEXT: int

WEBVIEW_FIND_WRAP: int

WEBVIEW_FIND_ENTIRE_WORD: int

WEBVIEW_FIND_MATCH_CASE: int

WEBVIEW_FIND_HIGHLIGHT_RESULT: int

WEBVIEW_FIND_BACKWARDS: int

WEBVIEW_FIND_DEFAULT: int

WEBVIEW_ZOOM_TINY: int

WEBVIEW_ZOOM_SMALL: int

WEBVIEW_ZOOM_MEDIUM: int

WEBVIEW_ZOOM_LARGE: int

WEBVIEW_ZOOM_LARGEST: int

WEBVIEWIE_EMU_DEFAULT: int

WEBVIEWIE_EMU_IE7: int

WEBVIEWIE_EMU_IE8: int

WEBVIEWIE_EMU_IE8_FORCE: int

WEBVIEWIE_EMU_IE9: int

WEBVIEWIE_EMU_IE9_FORCE: int

WEBVIEWIE_EMU_IE10: int

WEBVIEWIE_EMU_IE10_FORCE: int

WEBVIEWIE_EMU_IE11: int

WEBVIEWIE_EMU_IE11_FORCE: int

WEBVIEW_RELOAD_DEFAULT: int

WEBVIEW_RELOAD_NO_CACHE: int

WEBVIEW_NAV_ERR_CONNECTION: int

WEBVIEW_NAV_ERR_CERTIFICATE: int

WEBVIEW_NAV_ERR_AUTH: int

WEBVIEW_NAV_ERR_SECURITY: int

WEBVIEW_NAV_ERR_NOT_FOUND: int

WEBVIEW_NAV_ERR_REQUEST: int

WEBVIEW_NAV_ERR_USER_CANCELLED: int

WEBVIEW_NAV_ERR_OTHER: int

WEBVIEW_NAV_ACTION_NONE: int

WEBVIEW_NAV_ACTION_USER: int

WEBVIEW_NAV_ACTION_OTHER: int

